@@ -59,7 +59,7 @@ class TagsView(ValidatingView):
         async with self.request.app['db_pool'].acquire() as conn:
             try:
                 await conn.execute('INSERT INTO tags (mac, uuid, major, minor, type, zone_id, name, group_id, bid, attrs) VALUES '
-                                   '($1, $2, $3, $4, $5, $6, $7, $8, $9)',
+                                   '($1, $2, $3, $4, $5, $6, $7, $8, $9, $10)',
                                    new_t.get('mac', None),
                                    new_t.get('uuid', None),
                                    new_t.get('major', None),
