@@ -7,8 +7,10 @@ import signal
 
 import click
 
-from .protocol import ListenerProtocol
+from .protocol import ListenerProtocol, start_packet_tasks
+from ..config import CONFIG
 from ..db import init_db_pool
+import c3loc.stats as stats
 
 
 def default_handler(loop, context):
@@ -27,6 +29,9 @@ def main(port) -> None:
     db_pool = loop.run_until_complete(init_db_pool())
     ListenerProtocol.db_pool = db_pool
 
+    stats.run(CONFIG['STATS_INTERVAL'])
+    start_packet_tasks()
+
     def start_server(loop):
         return loop.create_server(ListenerProtocol, '0.0.0.0', port)
     server = loop.run_until_complete(start_server(loop))
